@@ -62,37 +62,37 @@ PaymentBotHandlersCfg: HandlersCfgType = {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.SET_TEST_MODE_CMD),
-            "filters": filters.command(["set_test_mode"]),
+            "filters": filters.command(["paybot_set_test_mode"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.IS_TEST_MODE_CMD),
-            "filters": filters.command(["is_test_mode"]),
+            "filters": filters.command(["paybot_is_test_mode"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.AUTH_USERS_CMD),
-            "filters": filters.command(["auth_users"]),
+            "filters": filters.command(["paybot_auth_users"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.CHAT_INFO_CMD),
-            "filters": filters.command(["chat_info"]),
+            "filters": filters.command(["paybot_chat_info"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.USERS_LIST_CMD),
-            "filters": filters.command(["users_list"]),
+            "filters": filters.command(["paybot_users_list"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.INVITE_LINKS_CMD),
-            "filters": filters.command(["invite_link"]),
+            "filters": filters.command(["paybot_invite_link"]),
         },
 
         #
@@ -103,13 +103,13 @@ PaymentBotHandlersCfg: HandlersCfgType = {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.CHECK_NO_USERNAME_CMD),
-            "filters": filters.command(["check_no_username"]),
+            "filters": filters.command(["paybot_check_username"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.REMOVE_NO_USERNAME_CMD),
-            "filters": filters.command(["remove_no_username"]),
+            "filters": filters.command(["paybot_remove_username"]),
         },
 
         #
@@ -120,37 +120,37 @@ PaymentBotHandlersCfg: HandlersCfgType = {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.SET_CHECK_PAYMENT_ON_JOIN),
-            "filters": filters.command(["set_check_payment_on_join"]),
+            "filters": filters.command(["paybot_set_check_on_join"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.IS_CHECK_PAYMENT_ON_JOIN),
-            "filters": filters.command(["is_check_payment_on_join"]),
+            "filters": filters.command(["paybot_is_check_on_join"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.CHECK_PAYMENTS_DATA_CMD),
-            "filters": filters.command(["check_payments_data"]),
+            "filters": filters.command(["paybot_check_data"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.EMAIL_NO_PAYMENT_CMD),
-            "filters": filters.command(["email_no_payment"]),
+            "filters": filters.command(["paybot_email_payment"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.CHECK_NO_PAYMENT_CMD),
-            "filters": filters.command(["check_no_payment"]),
+            "filters": filters.command(["paybot_check_payment"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.REMOVE_NO_PAYMENT_CMD),
-            "filters": filters.command(["remove_no_payment"]),
+            "filters": filters.command(["paybot_remove_payment"]),
         },
 
         #
@@ -162,42 +162,42 @@ PaymentBotHandlersCfg: HandlersCfgType = {
                                                                            message,
                                                                            CommandTypes.PAYMENT_TASK_START_CMD,
                                                                            payments_check_scheduler=self.payments_check_scheduler),
-            "filters": filters.command(["payment_task_start"]),
+            "filters": filters.command(["paybot_task_start"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.PAYMENT_TASK_STOP_CMD,
                                                                            payments_check_scheduler=self.payments_check_scheduler),
-            "filters": filters.command(["payment_task_stop"]),
+            "filters": filters.command(["paybot_task_stop"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.PAYMENT_TASK_ADD_CHAT_CMD,
                                                                            payments_check_scheduler=self.payments_check_scheduler),
-            "filters": filters.command(["payment_task_add_chat"]),
+            "filters": filters.command(["paybot_task_add_chat"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.PAYMENT_TASK_REMOVE_CHAT_CMD,
                                                                            payments_check_scheduler=self.payments_check_scheduler),
-            "filters": filters.command(["payment_task_remove_chat"]),
+            "filters": filters.command(["paybot_task_remove_chat"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.PAYMENT_TASK_REMOVE_ALL_CHATS_CMD,
                                                                            payments_check_scheduler=self.payments_check_scheduler),
-            "filters": filters.command(["payment_task_remove_all_chats"]),
+            "filters": filters.command(["paybot_task_remove_all_chats"]),
         },
         {
             "callback": lambda self, client, message: self.DispatchCommand(client,
                                                                            message,
                                                                            CommandTypes.PAYMENT_TASK_INFO_CMD,
                                                                            payments_check_scheduler=self.payments_check_scheduler),
-            "filters": filters.command(["payment_task_info"]),
+            "filters": filters.command(["paybot_task_info"]),
         },
 
         #
